==> dojo-1.8.1.jar: META-INF/resources/webjars/dojo/1.8.1/dojo/cldr/nls/fr/buddhist.js.uncompressed.js <==
define(
"dojo/cldr/nls/fr/buddhist", //begin v1.x content
{
	"eraNames": [
		"ère bouddhiste"
	],
	"eraAbbr": [
		"ère b."
	],
	"eraNarrow": "E.B.",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormat-long": "d MMMM y G",
	"dateFormat-medium": "d MMM, y G",
	"dateFormat-short": "d/M/yyyy",
	"dateFormatItem-d": "d",
	"dateFormatItem-Ed": "E d",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-MEd": "E d/M",
	"dateFormatItem-MMd": "d/MM",
	"dateFormatItem-MMdd": "dd/MM",
	"dateFormatItem-MMM": "LLL",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MMMdd": "dd MMM",
	"dateFormatItem-MMMEd": "E d MMM",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-y": "y G",
	"dateFormatItem-yM": "M/y G",
	"dateFormatItem-yMd": "d/M/y G",
	"dateFormatItem-yMEd": "E d/M/y G",
	"dateFormatItem-yMMM": "MMM y G",
	"dateFormatItem-yMMMEd": "E d MMM y G",
	"dateFormatItem-yQ": "'T'Q y G",
	"dateFormatItem-yQQQ": "QQQ y G",
	"dateFormatItem-yyMM": "MM/y G",
	"dateFormatItem-yyMMM": "MMM y G",
	"dateFormatItem-yyMMMd": "d MMM y G",
	"dateFormatItem-yyMMMEd": "E d MMM y G",
	"dateFormatItem-yyQ": "'T'Q y G",
	"dateFormatItem-yyQQQQ": "QQQQ y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-format-narrow": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dayPeriods-format-narrow-pm": "p",
	"dateFormatItem-yMMMd": "d MMM y",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	]
}
//end v1.x content
);

==> dojo-1.8.3.jar: META-INF/resources/webjars/dojo/1.8.3/dojo/cldr/nls/fr/buddhist.js.uncompressed.js <==
define(
"dojo/cldr/nls/fr/buddhist", //begin v1.x content
{
	"dateFormatItem-yM": "M/y G",
	"dateFormatItem-yQ": "'T'Q y G",
	"eraNames": [
		"ère bouddhiste"
	],
	"dateFormatItem-MMMEd": "E d MMM",
	"dateFormatItem-yQQQ": "QQQ y G",
	"dateFormatItem-MMdd": "dd/MM",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"dateFormatItem-MMM": "LLL",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dateFormatItem-Gy": "y G",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-y": "y G",
	"dateFormatItem-MMMdd": "dd MMM",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dateFormatItem-Ed": "E d",
	"dateFormatItem-yMMM": "MMM y G",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"eraAbbr": [
		"ère b."
	],
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-MMd": "d/MM",
	"dateFormatItem-yyMM": "MM/y G",
	"dateFormat-medium": "d MMM, y G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormatItem-yyMMM": "MMM y G",
	"dateFormatItem-yyQQQQ": "QQQQ y G",
	"dateFormatItem-yMd": "d/M/y G",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-yyMMMd": "d MMM y G",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-yyMMMEd": "E d MMM y G",
	"dateFormatItem-yyQ": "'T'Q y G",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateFormatItem-M": "L",
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-MEd": "E d/M",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-standAlone-short": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateFormat-short": "d/M/yyyy",
	"dateFormatItem-yMMMEd": "E d MMM y G",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMEd": "E d/M/y G",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormatItem-d": "d",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"eraNarrow": "E.B.",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	]
}
//end v1.x content
);
